@@ -565,6 +565,8 @@ static GobanOut  editPressed(void *packet)  {
 
 static void  saveFile(AbutFsel *fsel, void *packet, const char *fname)  {
   Local  *l = packet;
+  int error;
+  Str str;
 
   assert(MAGIC(l));
   str_copy(&l->cg->lastDirAccessed, &fsel->pathVal);
@@ -572,7 +574,13 @@ static void  saveFile(AbutFsel *fsel, void *packet, const char *fname)  {
     readGobanComments(l);
     l->modified = FALSE;
     clp_setStr(l->cg->clp, "local.sgfName", butTextin_get(fsel->in));
-    sgf_writeFile(l->moves, fname, NULL);
+    if (!sgf_writeFile(l->moves, fname, &error)) {
+      str_init(&str);
+      str_print(&str, "Error saving file \"%s\": %s",
+		fname, strerror(errno));
+      cgoban_createMsgWindow(l->cg, "Cgoban Error", str_chars(&str));
+      str_deinit(&str);
+    }
   }
   l->fsel = NULL;
 }
